Imports System.IO

Public Class Form1
    Private m_FileName As String
    Private m_IsDirty As Boolean

    ' Load a file and set the form's MdiParent.
    Public Sub LoadFile(ByVal file_name As String, ByVal mdi_parent As MDIParent1)
        ' Save the file name and MdiParent.
        m_FileName = file_name
        Me.MdiParent = mdi_parent

        ' Load the file.
        txtContents.Text = File.ReadAllText(m_FileName)
        txtContents.Select(0, 0)

        ' Display the file name.
        Me.Text = New FileInfo(m_FileName).Name

        ' The data has not been modified since it was loaded.
        m_IsDirty = False
    End Sub

    ' Close the form.
    Private Sub mnuFileClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuFileClose.Click
        Me.Close()
    End Sub

    ' See if it's safe to close the form.
    Private Sub mdiChild_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        If m_IsDirty Then
            ' There are unsaved changes.
            ' Ask the user if we should save them.
            Select Case MessageBox.Show( _
                    "The data has changed. Save the changes?", _
                    "Save Changes?", _
                    MessageBoxButtons.YesNoCancel, _
                    MessageBoxIcon.Question)
                Case Windows.Forms.DialogResult.Yes
                    ' Save the changes.
                    SaveFile()

                    ' See if we succeeded.
                    e.Cancel = m_IsDirty
                Case Windows.Forms.DialogResult.No
                    ' Discard the changes.
                    ' Leave e.Cancel = False.
                Case Windows.Forms.DialogResult.Cancel
                    ' Cancel the close.
                    e.Cancel = True
            End Select
        End If
    End Sub

    ' Save the file.
    Private Sub SaveFile()
        File.WriteAllText(m_FileName, txtContents.Text)
        m_IsDirty = False
        Me.Text = New FileInfo(m_FileName).Name
    End Sub

    ' Mark the data as modified.
    Private Sub txtContents_TextChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles txtContents.TextChanged
        m_IsDirty = True
        If Not Me.Text.EndsWith("*") Then
            Me.Text = New FileInfo(m_FileName).Name & "*"
        End If
    End Sub

    ' Save the changes.
    Private Sub mnuFileSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuFileSave.Click
        SaveFile()
    End Sub
End Class
