Imports System.Data
Imports System.Data.OleDb
Imports System.IO

Public Class Form1
    Private Sub Form1_Load(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles MyBase.Load
        ' Make the DataSet.
        Dim scores_dataset As New DataSet("Scores")

        ' Make the Students table.
        Dim students_table As DataTable = _
            scores_dataset.Tables.Add("Students")

        ' Add columns to the Students table.
        students_table.Columns.Add("FirstName", GetType(String))
        students_table.Columns.Add("LastName", GetType(String))
        students_table.Columns.Add("StudentId", GetType(Integer))

        ' Make the StudentId field unique.
        students_table.Columns("StudentId").Unique = True

        ' Make the combined FirstName/LastName unique.
        Dim first_last_columns() As DataColumn = { _
            students_table.Columns("FirstName"), _
            students_table.Columns("LastName") _
        }
        students_table.Constraints.Add( _
            New UniqueConstraint(first_last_columns))

        ' Make the TestScores table.
        Dim test_scores_table As DataTable = _
            scores_dataset.Tables.Add("TestScores")

        ' Add columns to the TestScores table.
        test_scores_table.Columns.Add("StudentId", GetType(Integer))
        test_scores_table.Columns.Add("TestNumber", GetType(Integer))
        test_scores_table.Columns.Add("Score", GetType(Integer))

        ' Make the combined StudentId/TestNumber unique.
        Dim studentid_testnumber_score_columns() As DataColumn = { _
            test_scores_table.Columns("StudentId"), _
            test_scores_table.Columns("TestNumber") _
        }
        test_scores_table.Constraints.Add( _
            New UniqueConstraint(studentid_testnumber_score_columns))

        ' Make a relationship linking the
        ' two tables' StudentId fields.
        scores_dataset.Relations.Add( _
            "Student Test Scores", _
            students_table.Columns("StudentId"), _
            test_scores_table.Columns("StudentId"))

        ' Make some student data.
        students_table.Rows.Add(New Object() {"Art", "Ant", 1})
        students_table.Rows.Add(New Object() {"Bev", "Bug", 2})
        students_table.Rows.Add(New Object() {"Cid", "Cat", 3})
        students_table.Rows.Add(New Object() {"Deb", "Dove", 4})

        ' Make some random test scores.
        Dim score As New Random
        For id As Integer = 1 To 4
            For test_num As Integer = 1 To 10
                test_scores_table.Rows.Add( _
                    New Object() {id, test_num, score.Next(65, 100)})
            Next test_num
        Next id

        ' Map the columns.
        'students_table.Columns("FirstName").ColumnMapping = MappingType.Attribute
        'students_table.Columns("LastName").ColumnMapping = MappingType.Attribute
        'students_table.Columns("StudentId").ColumnMapping = MappingType.SimpleContent

        students_table.Columns("FirstName").ColumnMapping = MappingType.Element
        students_table.Columns("LastName").ColumnMapping = MappingType.Element
        students_table.Columns("StudentId").ColumnMapping = MappingType.Attribute

        ' Display the XML.
        Dim string_writer As New StringWriter()
        students_table.WriteXml(string_writer)
        Dim txt As String = string_writer.ToString()
        Debug.WriteLine(txt)

        ' Attach the DataSet to the DataGrid.
        grdScores.DataSource = scores_dataset
    End Sub
End Class
