Imports System.Windows.Forms
Imports System.Data
Imports System.Data.OleDb

Public Class Form1
    ' The data source.
    Private m_ContactsTable As DataTable

    ' The data source's CurrencyManager.
    Private m_CurrencyManager As CurrencyManager

    Private Sub Form1_Load(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles MyBase.Load
        ' Make a DataTable.
        m_ContactsTable = New DataTable("Contacts")

        ' Add columns.
        m_ContactsTable.Columns.Add("FirstName", GetType(String))
        m_ContactsTable.Columns.Add("LastName", GetType(String))
        m_ContactsTable.Columns.Add("Street", GetType(String))
        m_ContactsTable.Columns.Add("City", GetType(String))
        m_ContactsTable.Columns.Add("State", GetType(String))
        m_ContactsTable.Columns.Add("Zip", GetType(String))

        ' Make the combined FirstName/LastName unique.
        Dim first_last_columns() As DataColumn = { _
            m_ContactsTable.Columns("FirstName"), _
            m_ContactsTable.Columns("LastName") _
        }
        m_ContactsTable.Constraints.Add( _
            New UniqueConstraint(first_last_columns))

        ' Make some contact data.
        m_ContactsTable.Rows.Add(New Object() {"Art", "Ant", _
            "1234 Ash Pl", "Bugville", "CO", "11111"})
        m_ContactsTable.Rows.Add(New Object() {"Bev", "Bug", _
            "22 Beach St", "Bugville", "CO", "22222"})
        m_ContactsTable.Rows.Add(New Object() {"Cid", "Cat", _
            "3 Road Place Lane", "Programmeria", "KS", "33333"})
        m_ContactsTable.Rows.Add(New Object() {"Deb", "Dove", _
            "414 Debugger Way", "Programmeria", "KS", "44444"})
        m_ContactsTable.Rows.Add(New Object() {"Ed", "Eager", _
            "5746 Elm Blvd", "Bugville", "CO", "55555"})
        m_ContactsTable.Rows.Add(New Object() {"Fran", "Fix", _
            "647 Foxglove Ct", "Bugville", "CO", "66666"})
        m_ContactsTable.Rows.Add(New Object() {"Gus", "Gantry", _
            "71762-B Gooseberry Ave", "Programmeria", "KS", "77777"})
        m_ContactsTable.Rows.Add(New Object() {"Hil", "Harris", _
            "828 Hurryup St", "Programmeria", "KS", "88888"})

        ' Bind to controls.
        txtFirstName.DataBindings.Add("Text", m_ContactsTable, "FirstName")
        txtLastName.DataBindings.Add("Text", m_ContactsTable, "LastName")
        txtStreet.DataBindings.Add("Text", m_ContactsTable, "Street")
        txtCity.DataBindings.Add("Text", m_ContactsTable, "City")
        txtState.DataBindings.Add("Text", m_ContactsTable, "State")
        txtZip.DataBindings.Add("Text", m_ContactsTable, "Zip")

        ' Save a reference to the CurrencyManager.
        m_CurrencyManager = _
            DirectCast(Me.BindingContext(m_ContactsTable), CurrencyManager)
    End Sub

    Private Sub btnFirst_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnFirst.Click
        m_CurrencyManager.Position = 0
    End Sub

    Private Sub btnPrev_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnPrev.Click
        m_CurrencyManager.Position -= 1
    End Sub

    Private Sub btnNext_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnNext.Click
        m_CurrencyManager.Position += 1
    End Sub

    Private Sub btnLast_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnLast.Click
        m_CurrencyManager.Position = m_CurrencyManager.Count - 1
    End Sub

    ' Add a new record.
    Private Sub btnAdd_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnAdd.Click
        m_CurrencyManager.AddNew()
    End Sub

    Private Sub btnDelete_Click(ByVal sender As System.Object, _
     ByVal e As System.EventArgs) Handles btnDelete.Click
        If MsgBox("Are you sure you want to delete this record?", _
            MsgBoxStyle.Question Or MsgBoxStyle.YesNo, _
            "Confirm Delete?") = MsgBoxResult.Yes _
        Then
            m_CurrencyManager.RemoveAt(m_CurrencyManager.Position)
        End If
    End Sub
End Class
