' Requires a reference to System.Xml.
Imports System.Xml.Serialization
Imports System.IO

Public Class frmDragEmployee
    Public Const DATA_EMPLOYEE As String = "DragEmployee.frmDragEmployee+Employee"

    ' If you comment out the Serializable attribute,
    ' the program still works if you drag from the drag
    ' source to the drop target within the same instance
    ' of the application but it won't drag from one instance
    ' of the program to another.
    <Serializable()> _
    Public Class Employee
        Public FirstName As String
        Public LastName As String
        Public Sub New()
        End Sub
        Public Sub New(ByVal first_name As String, ByVal last_name As String)
            FirstName = first_name
            LastName = last_name
        End Sub
    End Class

    ' Start dragging the Employee.
    Private Sub lblDragSource_MouseDown(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles lblDragSource.MouseDown
        Dim emp As New Employee(txtFirstName.Text, txtLastName.Text)
        If lblDragSource.DoDragDrop(emp, _
            DragDropEffects.Copy Or DragDropEffects.Move) = DragDropEffects.Move _
        Then
            ' A Move succeeded. Clear the TextBoxes.
            txtFirstName.Text = ""
            txtLastName.Text = ""
        End If
    End Sub

    ' If an Employee object is available, allow a Move
    ' or Copy depending on whether the Ctrl key is pressed.
    Private Sub lblDropTarget_DragOver(ByVal sender As Object, ByVal e As System.Windows.Forms.DragEventArgs) Handles lblDropTarget.DragOver
        If e.Data.GetDataPresent(DATA_EMPLOYEE) Then
            ' Display the Move or Copy cursor.
            Const KEY_CTRL As Integer = 8
            If (e.KeyState And KEY_CTRL) <> 0 Then
                e.Effect = DragDropEffects.Copy
            Else
                e.Effect = DragDropEffects.Move
            End If
        End If
    End Sub

    ' Display the dropped Employee object.
    Private Sub lblDropTarget_DragDrop(ByVal sender As Object, ByVal e As System.Windows.Forms.DragEventArgs) Handles lblDropTarget.DragDrop
        Dim emp As Employee = DirectCast(e.Data.GetData(DATA_EMPLOYEE), Employee)
        lblFirstName.Text = emp.FirstName
        lblLastName.Text = emp.LastName
    End Sub

    ' Display the Employee object's serialization.
    Private Sub btnShowSerialization_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnShowSerialization.Click
        Dim emp As New Employee(txtFirstName.Text, txtLastName.Text)
        Dim string_writer As New StringWriter()
        Dim serializer As New XmlSerializer(GetType(Employee))
        serializer.Serialize(string_writer, emp)
        MessageBox.Show(string_writer.ToString, _
            "Serialization", MessageBoxButtons.OK, _
            MessageBoxIcon.Information)
    End Sub
End Class
